# Generated by Django 2.2.14 on 2020-10-13 08:31

from django.db import migrations, models
import django.db.models.deletion
import modelcluster.fields
import wagtail.core.blocks
import wagtail.core.fields


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('wagtailcore', '0052_pagelogentry'),
    ]

    operations = [
        migrations.CreateModel(
            name='EmailFormPage',
            fields=[
                ('page_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, serialize=False, to='wagtailcore.Page')),
                ('to_address', models.CharField(blank=True, help_text='Optional - form submissions will be emailed to these addresses. Separate multiple addresses by comma.', max_length=255, verbose_name='to address')),
                ('from_address', models.CharField(blank=True, max_length=255, verbose_name='from address')),
                ('subject', models.CharField(blank=True, max_length=255, verbose_name='subject')),
                ('form', wagtail.core.fields.StreamField([('singleline', wagtail.core.blocks.StructBlock([('label', wagtail.core.blocks.CharBlock(help_text='The label of the form field.', max_length=255, required=True)), ('required', wagtail.core.blocks.BooleanBlock(default=False, help_text='Tick this box to make this a required field.', required=False)), ('max_length', wagtail.core.blocks.IntegerBlock(help_text='Set a maximum length for this field. e.g. 100', required=False)), ('default_value', wagtail.core.blocks.CharBlock(help_text='Set a default value for this field.', max_length=255, required=False)), ('help_text', wagtail.core.blocks.CharBlock(help_text='Text to assist the user in populating this field.', max_length=255, required=False)), ('rules', wagtail.core.blocks.StructBlock([('action', wagtail.core.blocks.ChoiceBlock(choices=[('show', 'Show'), ('hide', 'Hide')], help_text='What conditional action would you like to perform on this field?')), ('conditions', wagtail.core.blocks.StreamBlock([('condition', wagtail.core.blocks.StructBlock([('field_name', wagtail.core.blocks.CharBlock(help_text='The name of a field in the form', max_length=255, required=True)), ('rule', wagtail.core.blocks.ChoiceBlock(choices=[('is', 'Is equal to'), ('is_not', 'Is not equal to'), ('greater_than', 'Greater than'), ('greater_than_equal', 'Greater than or equal to'), ('less_than', 'Less than'), ('less_than_equal', 'Less than or equal to'), ('contains', 'Contains'), ('starts-with', 'Starts with'), ('ends-with', 'Ends with')])), ('value', wagtail.core.blocks.CharBlock(help_text='', max_length=255, required=True))])), ('blank_condition', wagtail.core.blocks.StructBlock([('field_name', wagtail.core.blocks.CharBlock(help_text='The name of a field in the form', max_length=255, required=True)), ('rule', wagtail.core.blocks.ChoiceBlock(choices=[('is_blank', 'Is blank'), ('is_not_blank', 'Is not blank')]))]))], required=False))], help_text='Add conditional rules to show or hide fields depending on the value of other fields in the form.', required=False))], label='Basic field')), ('email', wagtail.core.blocks.StructBlock([('label', wagtail.core.blocks.CharBlock(help_text='The label of the form field.', max_length=255, required=True)), ('required', wagtail.core.blocks.BooleanBlock(default=False, help_text='Tick this box to make this a required field.', required=False)), ('max_length', wagtail.core.blocks.IntegerBlock(help_text='Set a maximum length for this field. e.g. 100', required=False)), ('default_value', wagtail.core.blocks.CharBlock(help_text='Set a default value for this field.', max_length=255, required=False)), ('help_text', wagtail.core.blocks.CharBlock(help_text='Text to assist the user in populating this field.', max_length=255, required=False)), ('rules', wagtail.core.blocks.StructBlock([('action', wagtail.core.blocks.ChoiceBlock(choices=[('show', 'Show'), ('hide', 'Hide')], help_text='What conditional action would you like to perform on this field?')), ('conditions', wagtail.core.blocks.StreamBlock([('condition', wagtail.core.blocks.StructBlock([('field_name', wagtail.core.blocks.CharBlock(help_text='The name of a field in the form', max_length=255, required=True)), ('rule', wagtail.core.blocks.ChoiceBlock(choices=[('is', 'Is equal to'), ('is_not', 'Is not equal to'), ('greater_than', 'Greater than'), ('greater_than_equal', 'Greater than or equal to'), ('less_than', 'Less than'), ('less_than_equal', 'Less than or equal to'), ('contains', 'Contains'), ('starts-with', 'Starts with'), ('ends-with', 'Ends with')])), ('value', wagtail.core.blocks.CharBlock(help_text='', max_length=255, required=True))])), ('blank_condition', wagtail.core.blocks.StructBlock([('field_name', wagtail.core.blocks.CharBlock(help_text='The name of a field in the form', max_length=255, required=True)), ('rule', wagtail.core.blocks.ChoiceBlock(choices=[('is_blank', 'Is blank'), ('is_not_blank', 'Is not blank')]))]))], required=False))], help_text='Add conditional rules to show or hide fields depending on the value of other fields in the form.', required=False))], label='Email field')), ('html', wagtail.core.blocks.StructBlock([('label', wagtail.core.blocks.CharBlock(help_text='A unique reference for this html block', label='Unique reference name', max_length=255, required=True)), ('html', wagtail.core.blocks.RichTextBlock(required=True)), ('rules', wagtail.core.blocks.StructBlock([('action', wagtail.core.blocks.ChoiceBlock(choices=[('show', 'Show'), ('hide', 'Hide')], help_text='What conditional action would you like to perform on this field?')), ('conditions', wagtail.core.blocks.StreamBlock([('condition', wagtail.core.blocks.StructBlock([('field_name', wagtail.core.blocks.CharBlock(help_text='The name of a field in the form', max_length=255, required=True)), ('rule', wagtail.core.blocks.ChoiceBlock(choices=[('is', 'Is equal to'), ('is_not', 'Is not equal to'), ('greater_than', 'Greater than'), ('greater_than_equal', 'Greater than or equal to'), ('less_than', 'Less than'), ('less_than_equal', 'Less than or equal to'), ('contains', 'Contains'), ('starts-with', 'Starts with'), ('ends-with', 'Ends with')])), ('value', wagtail.core.blocks.CharBlock(help_text='', max_length=255, required=True))])), ('blank_condition', wagtail.core.blocks.StructBlock([('field_name', wagtail.core.blocks.CharBlock(help_text='The name of a field in the form', max_length=255, required=True)), ('rule', wagtail.core.blocks.ChoiceBlock(choices=[('is_blank', 'Is blank'), ('is_not_blank', 'Is not blank')]))]))], required=False))], help_text='Add conditional rules to show or hide fields depending on the value of other fields in the form.', required=False))], label='HTML')), ('dropdown', wagtail.core.blocks.StructBlock([('label', wagtail.core.blocks.CharBlock(help_text='The label of the form field.', max_length=255, required=True)), ('required', wagtail.core.blocks.BooleanBlock(default=False, help_text='Tick this box to make this a required field.', required=False)), ('choices', wagtail.core.blocks.ListBlock(wagtail.core.blocks.TextBlock(icon='extraicons--heading-icon', required=True))), ('empty_label', wagtail.core.blocks.CharBlock(max_length=255, required=False)), ('default_value', wagtail.core.blocks.CharBlock(help_text='Set a default value for this field.', max_length=255, required=False)), ('help_text', wagtail.core.blocks.CharBlock(help_text='Text to assist the user in populating this field.', max_length=255, required=False)), ('rules', wagtail.core.blocks.StructBlock([('action', wagtail.core.blocks.ChoiceBlock(choices=[('show', 'Show'), ('hide', 'Hide')], help_text='What conditional action would you like to perform on this field?')), ('conditions', wagtail.core.blocks.StreamBlock([('condition', wagtail.core.blocks.StructBlock([('field_name', wagtail.core.blocks.CharBlock(help_text='The name of a field in the form', max_length=255, required=True)), ('rule', wagtail.core.blocks.ChoiceBlock(choices=[('is', 'Is equal to'), ('is_not', 'Is not equal to'), ('greater_than', 'Greater than'), ('greater_than_equal', 'Greater than or equal to'), ('less_than', 'Less than'), ('less_than_equal', 'Less than or equal to'), ('contains', 'Contains'), ('starts-with', 'Starts with'), ('ends-with', 'Ends with')])), ('value', wagtail.core.blocks.CharBlock(help_text='', max_length=255, required=True))])), ('blank_condition', wagtail.core.blocks.StructBlock([('field_name', wagtail.core.blocks.CharBlock(help_text='The name of a field in the form', max_length=255, required=True)), ('rule', wagtail.core.blocks.ChoiceBlock(choices=[('is_blank', 'Is blank'), ('is_not_blank', 'Is not blank')]))]))], required=False))], help_text='Add conditional rules to show or hide fields depending on the value of other fields in the form.', required=False))], label='Dropdown field')), ('radio', wagtail.core.blocks.StructBlock([('label', wagtail.core.blocks.CharBlock(help_text='The label of the form field.', max_length=255, required=True)), ('required', wagtail.core.blocks.BooleanBlock(default=False, help_text='Tick this box to make this a required field.', required=False)), ('choices', wagtail.core.blocks.ListBlock(wagtail.core.blocks.TextBlock(icon='extraicons--heading-icon', required=True))), ('default_value', wagtail.core.blocks.CharBlock(help_text='Set a default value for this field.', max_length=255, required=False)), ('help_text', wagtail.core.blocks.CharBlock(help_text='Text to assist the user in populating this field.', max_length=255, required=False)), ('display_side_by_side', wagtail.core.blocks.BooleanBlock(help_text='Display these items side by side?', required=False)), ('rules', wagtail.core.blocks.StructBlock([('action', wagtail.core.blocks.ChoiceBlock(choices=[('show', 'Show'), ('hide', 'Hide')], help_text='What conditional action would you like to perform on this field?')), ('conditions', wagtail.core.blocks.StreamBlock([('condition', wagtail.core.blocks.StructBlock([('field_name', wagtail.core.blocks.CharBlock(help_text='The name of a field in the form', max_length=255, required=True)), ('rule', wagtail.core.blocks.ChoiceBlock(choices=[('is', 'Is equal to'), ('is_not', 'Is not equal to'), ('greater_than', 'Greater than'), ('greater_than_equal', 'Greater than or equal to'), ('less_than', 'Less than'), ('less_than_equal', 'Less than or equal to'), ('contains', 'Contains'), ('starts-with', 'Starts with'), ('ends-with', 'Ends with')])), ('value', wagtail.core.blocks.CharBlock(help_text='', max_length=255, required=True))])), ('blank_condition', wagtail.core.blocks.StructBlock([('field_name', wagtail.core.blocks.CharBlock(help_text='The name of a field in the form', max_length=255, required=True)), ('rule', wagtail.core.blocks.ChoiceBlock(choices=[('is_blank', 'Is blank'), ('is_not_blank', 'Is not blank')]))]))], required=False))], help_text='Add conditional rules to show or hide fields depending on the value of other fields in the form.', required=False))], label='Radio field')), ('checkboxes', wagtail.core.blocks.StructBlock([('label', wagtail.core.blocks.CharBlock(help_text='The label of the form field.', max_length=255, required=True)), ('required', wagtail.core.blocks.BooleanBlock(default=False, help_text='Tick this box to make this a required field.', required=False)), ('choices', wagtail.core.blocks.ListBlock(wagtail.core.blocks.TextBlock(icon='extraicons--heading-icon', required=True))), ('default_value', wagtail.core.blocks.ListBlock(wagtail.core.blocks.TextBlock(help_text='Enter a value that matches a checkbox choice above to have it ticked by default.', icon='extraicons--heading-icon', required=True))), ('help_text', wagtail.core.blocks.CharBlock(help_text='Text to assist the user in populating this field.', max_length=255, required=False)), ('display_side_by_side', wagtail.core.blocks.BooleanBlock(help_text='Display these items side by side?', required=False)), ('rules', wagtail.core.blocks.StructBlock([('action', wagtail.core.blocks.ChoiceBlock(choices=[('show', 'Show'), ('hide', 'Hide')], help_text='What conditional action would you like to perform on this field?')), ('conditions', wagtail.core.blocks.StreamBlock([('condition', wagtail.core.blocks.StructBlock([('field_name', wagtail.core.blocks.CharBlock(help_text='The name of a field in the form', max_length=255, required=True)), ('rule', wagtail.core.blocks.ChoiceBlock(choices=[('is', 'Is equal to'), ('is_not', 'Is not equal to'), ('greater_than', 'Greater than'), ('greater_than_equal', 'Greater than or equal to'), ('less_than', 'Less than'), ('less_than_equal', 'Less than or equal to'), ('contains', 'Contains'), ('starts-with', 'Starts with'), ('ends-with', 'Ends with')])), ('value', wagtail.core.blocks.CharBlock(help_text='', max_length=255, required=True))])), ('blank_condition', wagtail.core.blocks.StructBlock([('field_name', wagtail.core.blocks.CharBlock(help_text='The name of a field in the form', max_length=255, required=True)), ('rule', wagtail.core.blocks.ChoiceBlock(choices=[('is_blank', 'Is blank'), ('is_not_blank', 'Is not blank')]))]))], required=False))], help_text='Add conditional rules to show or hide fields depending on the value of other fields in the form.', required=False))], label='Checkboxes field')), ('checkbox', wagtail.core.blocks.StructBlock([('label', wagtail.core.blocks.CharBlock(help_text='The label of the form field.', max_length=255, required=True)), ('required', wagtail.core.blocks.BooleanBlock(default=False, help_text='Tick this box to make this a required field.', required=False)), ('display_checkbox_label', wagtail.core.blocks.BooleanBlock(default=False, help_text='Do you want the checkbox label to display? If not you should populate help_text.', required=False)), ('help_text', wagtail.core.blocks.CharBlock(max_length=255, required=False)), ('rules', wagtail.core.blocks.StructBlock([('action', wagtail.core.blocks.ChoiceBlock(choices=[('show', 'Show'), ('hide', 'Hide')], help_text='What conditional action would you like to perform on this field?')), ('conditions', wagtail.core.blocks.StreamBlock([('condition', wagtail.core.blocks.StructBlock([('field_name', wagtail.core.blocks.CharBlock(help_text='The name of a field in the form', max_length=255, required=True)), ('rule', wagtail.core.blocks.ChoiceBlock(choices=[('is', 'Is equal to'), ('is_not', 'Is not equal to'), ('greater_than', 'Greater than'), ('greater_than_equal', 'Greater than or equal to'), ('less_than', 'Less than'), ('less_than_equal', 'Less than or equal to'), ('contains', 'Contains'), ('starts-with', 'Starts with'), ('ends-with', 'Ends with')])), ('value', wagtail.core.blocks.CharBlock(help_text='', max_length=255, required=True))])), ('blank_condition', wagtail.core.blocks.StructBlock([('field_name', wagtail.core.blocks.CharBlock(help_text='The name of a field in the form', max_length=255, required=True)), ('rule', wagtail.core.blocks.ChoiceBlock(choices=[('is_blank', 'Is blank'), ('is_not_blank', 'Is not blank')]))]))], required=False))], help_text='Add conditional rules to show or hide fields depending on the value of other fields in the form.', required=False))], label='Checkbox field')), ('multiselect', wagtail.core.blocks.StructBlock([('label', wagtail.core.blocks.CharBlock(help_text='The label of the form field.', max_length=255, required=True)), ('required', wagtail.core.blocks.BooleanBlock(default=False, help_text='Tick this box to make this a required field.', required=False)), ('choices', wagtail.core.blocks.ListBlock(wagtail.core.blocks.TextBlock(icon='extraicons--heading-icon', required=True))), ('default_value', wagtail.core.blocks.CharBlock(help_text='Set a default value for this field.', max_length=255, required=False)), ('help_text', wagtail.core.blocks.CharBlock(help_text='Text to assist the user in populating this field.', max_length=255, required=False)), ('rules', wagtail.core.blocks.StructBlock([('action', wagtail.core.blocks.ChoiceBlock(choices=[('show', 'Show'), ('hide', 'Hide')], help_text='What conditional action would you like to perform on this field?')), ('conditions', wagtail.core.blocks.StreamBlock([('condition', wagtail.core.blocks.StructBlock([('field_name', wagtail.core.blocks.CharBlock(help_text='The name of a field in the form', max_length=255, required=True)), ('rule', wagtail.core.blocks.ChoiceBlock(choices=[('is', 'Is equal to'), ('is_not', 'Is not equal to'), ('greater_than', 'Greater than'), ('greater_than_equal', 'Greater than or equal to'), ('less_than', 'Less than'), ('less_than_equal', 'Less than or equal to'), ('contains', 'Contains'), ('starts-with', 'Starts with'), ('ends-with', 'Ends with')])), ('value', wagtail.core.blocks.CharBlock(help_text='', max_length=255, required=True))])), ('blank_condition', wagtail.core.blocks.StructBlock([('field_name', wagtail.core.blocks.CharBlock(help_text='The name of a field in the form', max_length=255, required=True)), ('rule', wagtail.core.blocks.ChoiceBlock(choices=[('is_blank', 'Is blank'), ('is_not_blank', 'Is not blank')]))]))], required=False))], help_text='Add conditional rules to show or hide fields depending on the value of other fields in the form.', required=False))], label='Multiselect field')), ('multiline', wagtail.core.blocks.StructBlock([('label', wagtail.core.blocks.CharBlock(help_text='The label of the form field.', max_length=255, required=True)), ('required', wagtail.core.blocks.BooleanBlock(default=False, help_text='Tick this box to make this a required field.', required=False)), ('default_value', wagtail.core.blocks.CharBlock(help_text='Set a default value for this field.', max_length=255, required=False)), ('help_text', wagtail.core.blocks.CharBlock(help_text='Text to assist the user in populating this field.', max_length=255, required=False)), ('rules', wagtail.core.blocks.StructBlock([('action', wagtail.core.blocks.ChoiceBlock(choices=[('show', 'Show'), ('hide', 'Hide')], help_text='What conditional action would you like to perform on this field?')), ('conditions', wagtail.core.blocks.StreamBlock([('condition', wagtail.core.blocks.StructBlock([('field_name', wagtail.core.blocks.CharBlock(help_text='The name of a field in the form', max_length=255, required=True)), ('rule', wagtail.core.blocks.ChoiceBlock(choices=[('is', 'Is equal to'), ('is_not', 'Is not equal to'), ('greater_than', 'Greater than'), ('greater_than_equal', 'Greater than or equal to'), ('less_than', 'Less than'), ('less_than_equal', 'Less than or equal to'), ('contains', 'Contains'), ('starts-with', 'Starts with'), ('ends-with', 'Ends with')])), ('value', wagtail.core.blocks.CharBlock(help_text='', max_length=255, required=True))])), ('blank_condition', wagtail.core.blocks.StructBlock([('field_name', wagtail.core.blocks.CharBlock(help_text='The name of a field in the form', max_length=255, required=True)), ('rule', wagtail.core.blocks.ChoiceBlock(choices=[('is_blank', 'Is blank'), ('is_not_blank', 'Is not blank')]))]))], required=False))], help_text='Add conditional rules to show or hide fields depending on the value of other fields in the form.', required=False))], label='Multiline field')), ('url', wagtail.core.blocks.StructBlock([('label', wagtail.core.blocks.CharBlock(help_text='The label of the form field.', max_length=255, required=True)), ('required', wagtail.core.blocks.BooleanBlock(default=False, help_text='Tick this box to make this a required field.', required=False)), ('max_length', wagtail.core.blocks.IntegerBlock(help_text='Set a maximum length for this field. e.g. 100', required=False)), ('default_value', wagtail.core.blocks.CharBlock(help_text='Set a default value for this field.', max_length=255, required=False)), ('help_text', wagtail.core.blocks.CharBlock(help_text='Text to assist the user in populating this field.', max_length=255, required=False)), ('rules', wagtail.core.blocks.StructBlock([('action', wagtail.core.blocks.ChoiceBlock(choices=[('show', 'Show'), ('hide', 'Hide')], help_text='What conditional action would you like to perform on this field?')), ('conditions', wagtail.core.blocks.StreamBlock([('condition', wagtail.core.blocks.StructBlock([('field_name', wagtail.core.blocks.CharBlock(help_text='The name of a field in the form', max_length=255, required=True)), ('rule', wagtail.core.blocks.ChoiceBlock(choices=[('is', 'Is equal to'), ('is_not', 'Is not equal to'), ('greater_than', 'Greater than'), ('greater_than_equal', 'Greater than or equal to'), ('less_than', 'Less than'), ('less_than_equal', 'Less than or equal to'), ('contains', 'Contains'), ('starts-with', 'Starts with'), ('ends-with', 'Ends with')])), ('value', wagtail.core.blocks.CharBlock(help_text='', max_length=255, required=True))])), ('blank_condition', wagtail.core.blocks.StructBlock([('field_name', wagtail.core.blocks.CharBlock(help_text='The name of a field in the form', max_length=255, required=True)), ('rule', wagtail.core.blocks.ChoiceBlock(choices=[('is_blank', 'Is blank'), ('is_not_blank', 'Is not blank')]))]))], required=False))], help_text='Add conditional rules to show or hide fields depending on the value of other fields in the form.', required=False))], label='URL field')), ('hidden', wagtail.core.blocks.StructBlock([('label', wagtail.core.blocks.CharBlock(help_text='The label of the form field.', max_length=255, required=True)), ('default_value', wagtail.core.blocks.CharBlock(max_length=255, required=True)), ('rules', wagtail.core.blocks.StructBlock([('action', wagtail.core.blocks.ChoiceBlock(choices=[('show', 'Show'), ('hide', 'Hide')], help_text='What conditional action would you like to perform on this field?')), ('conditions', wagtail.core.blocks.StreamBlock([('condition', wagtail.core.blocks.StructBlock([('field_name', wagtail.core.blocks.CharBlock(help_text='The name of a field in the form', max_length=255, required=True)), ('rule', wagtail.core.blocks.ChoiceBlock(choices=[('is', 'Is equal to'), ('is_not', 'Is not equal to'), ('greater_than', 'Greater than'), ('greater_than_equal', 'Greater than or equal to'), ('less_than', 'Less than'), ('less_than_equal', 'Less than or equal to'), ('contains', 'Contains'), ('starts-with', 'Starts with'), ('ends-with', 'Ends with')])), ('value', wagtail.core.blocks.CharBlock(help_text='', max_length=255, required=True))])), ('blank_condition', wagtail.core.blocks.StructBlock([('field_name', wagtail.core.blocks.CharBlock(help_text='The name of a field in the form', max_length=255, required=True)), ('rule', wagtail.core.blocks.ChoiceBlock(choices=[('is_blank', 'Is blank'), ('is_not_blank', 'Is not blank')]))]))], required=False))], help_text='Add conditional rules to show or hide fields depending on the value of other fields in the form.', required=False))], label='Hidden field')), ('number', wagtail.core.blocks.StructBlock([('label', wagtail.core.blocks.CharBlock(help_text='The label of the form field.', max_length=255, required=True)), ('required', wagtail.core.blocks.BooleanBlock(default=False, help_text='Tick this box to make this a required field.', required=False)), ('default_value', wagtail.core.blocks.CharBlock(help_text='Set a default value for this field.', max_length=255, required=False)), ('help_text', wagtail.core.blocks.CharBlock(help_text='Text to assist the user in populating this field.', max_length=255, required=False)), ('rules', wagtail.core.blocks.StructBlock([('action', wagtail.core.blocks.ChoiceBlock(choices=[('show', 'Show'), ('hide', 'Hide')], help_text='What conditional action would you like to perform on this field?')), ('conditions', wagtail.core.blocks.StreamBlock([('condition', wagtail.core.blocks.StructBlock([('field_name', wagtail.core.blocks.CharBlock(help_text='The name of a field in the form', max_length=255, required=True)), ('rule', wagtail.core.blocks.ChoiceBlock(choices=[('is', 'Is equal to'), ('is_not', 'Is not equal to'), ('greater_than', 'Greater than'), ('greater_than_equal', 'Greater than or equal to'), ('less_than', 'Less than'), ('less_than_equal', 'Less than or equal to'), ('contains', 'Contains'), ('starts-with', 'Starts with'), ('ends-with', 'Ends with')])), ('value', wagtail.core.blocks.CharBlock(help_text='', max_length=255, required=True))])), ('blank_condition', wagtail.core.blocks.StructBlock([('field_name', wagtail.core.blocks.CharBlock(help_text='The name of a field in the form', max_length=255, required=True)), ('rule', wagtail.core.blocks.ChoiceBlock(choices=[('is_blank', 'Is blank'), ('is_not_blank', 'Is not blank')]))]))], required=False))], help_text='Add conditional rules to show or hide fields depending on the value of other fields in the form.', required=False))], label='Number field'))], default=None, help_text='Add fields to the form', null=True)),
                ('thanks_page_title', models.CharField(blank=True, default=None, help_text='The title for the thanks page. Defaults to the normal page title if left blank.', max_length=150, null=True)),
                ('thanks_page_content', wagtail.core.fields.RichTextField(default=None, help_text='Content to display on the form thank you page.', null=True)),
                ('submit_button_text', models.CharField(default='Submit', help_text='The text to display on the form submission button', max_length=30)),
                ('use_browser_validation', models.BooleanField(blank=True, default=False, help_text='Tick this to use the in-built browser validation on fields')),
            ],
            options={
                'abstract': False,
            },
            bases=('wagtailcore.page', models.Model),
        ),
        migrations.CreateModel(
            name='FormPage',
            fields=[
                ('page_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, serialize=False, to='wagtailcore.Page')),
                ('form', wagtail.core.fields.StreamField([('singleline', wagtail.core.blocks.StructBlock([('label', wagtail.core.blocks.CharBlock(help_text='The label of the form field.', max_length=255, required=True)), ('required', wagtail.core.blocks.BooleanBlock(default=False, help_text='Tick this box to make this a required field.', required=False)), ('max_length', wagtail.core.blocks.IntegerBlock(help_text='Set a maximum length for this field. e.g. 100', required=False)), ('default_value', wagtail.core.blocks.CharBlock(help_text='Set a default value for this field.', max_length=255, required=False)), ('help_text', wagtail.core.blocks.CharBlock(help_text='Text to assist the user in populating this field.', max_length=255, required=False)), ('rules', wagtail.core.blocks.StructBlock([('action', wagtail.core.blocks.ChoiceBlock(choices=[('show', 'Show'), ('hide', 'Hide')], help_text='What conditional action would you like to perform on this field?')), ('conditions', wagtail.core.blocks.StreamBlock([('condition', wagtail.core.blocks.StructBlock([('field_name', wagtail.core.blocks.CharBlock(help_text='The name of a field in the form', max_length=255, required=True)), ('rule', wagtail.core.blocks.ChoiceBlock(choices=[('is', 'Is equal to'), ('is_not', 'Is not equal to'), ('greater_than', 'Greater than'), ('greater_than_equal', 'Greater than or equal to'), ('less_than', 'Less than'), ('less_than_equal', 'Less than or equal to'), ('contains', 'Contains'), ('starts-with', 'Starts with'), ('ends-with', 'Ends with')])), ('value', wagtail.core.blocks.CharBlock(help_text='', max_length=255, required=True))])), ('blank_condition', wagtail.core.blocks.StructBlock([('field_name', wagtail.core.blocks.CharBlock(help_text='The name of a field in the form', max_length=255, required=True)), ('rule', wagtail.core.blocks.ChoiceBlock(choices=[('is_blank', 'Is blank'), ('is_not_blank', 'Is not blank')]))]))], required=False))], help_text='Add conditional rules to show or hide fields depending on the value of other fields in the form.', required=False))], label='Basic field')), ('email', wagtail.core.blocks.StructBlock([('label', wagtail.core.blocks.CharBlock(help_text='The label of the form field.', max_length=255, required=True)), ('required', wagtail.core.blocks.BooleanBlock(default=False, help_text='Tick this box to make this a required field.', required=False)), ('max_length', wagtail.core.blocks.IntegerBlock(help_text='Set a maximum length for this field. e.g. 100', required=False)), ('default_value', wagtail.core.blocks.CharBlock(help_text='Set a default value for this field.', max_length=255, required=False)), ('help_text', wagtail.core.blocks.CharBlock(help_text='Text to assist the user in populating this field.', max_length=255, required=False)), ('rules', wagtail.core.blocks.StructBlock([('action', wagtail.core.blocks.ChoiceBlock(choices=[('show', 'Show'), ('hide', 'Hide')], help_text='What conditional action would you like to perform on this field?')), ('conditions', wagtail.core.blocks.StreamBlock([('condition', wagtail.core.blocks.StructBlock([('field_name', wagtail.core.blocks.CharBlock(help_text='The name of a field in the form', max_length=255, required=True)), ('rule', wagtail.core.blocks.ChoiceBlock(choices=[('is', 'Is equal to'), ('is_not', 'Is not equal to'), ('greater_than', 'Greater than'), ('greater_than_equal', 'Greater than or equal to'), ('less_than', 'Less than'), ('less_than_equal', 'Less than or equal to'), ('contains', 'Contains'), ('starts-with', 'Starts with'), ('ends-with', 'Ends with')])), ('value', wagtail.core.blocks.CharBlock(help_text='', max_length=255, required=True))])), ('blank_condition', wagtail.core.blocks.StructBlock([('field_name', wagtail.core.blocks.CharBlock(help_text='The name of a field in the form', max_length=255, required=True)), ('rule', wagtail.core.blocks.ChoiceBlock(choices=[('is_blank', 'Is blank'), ('is_not_blank', 'Is not blank')]))]))], required=False))], help_text='Add conditional rules to show or hide fields depending on the value of other fields in the form.', required=False))], label='Email field')), ('html', wagtail.core.blocks.StructBlock([('label', wagtail.core.blocks.CharBlock(help_text='A unique reference for this html block', label='Unique reference name', max_length=255, required=True)), ('html', wagtail.core.blocks.RichTextBlock(required=True)), ('rules', wagtail.core.blocks.StructBlock([('action', wagtail.core.blocks.ChoiceBlock(choices=[('show', 'Show'), ('hide', 'Hide')], help_text='What conditional action would you like to perform on this field?')), ('conditions', wagtail.core.blocks.StreamBlock([('condition', wagtail.core.blocks.StructBlock([('field_name', wagtail.core.blocks.CharBlock(help_text='The name of a field in the form', max_length=255, required=True)), ('rule', wagtail.core.blocks.ChoiceBlock(choices=[('is', 'Is equal to'), ('is_not', 'Is not equal to'), ('greater_than', 'Greater than'), ('greater_than_equal', 'Greater than or equal to'), ('less_than', 'Less than'), ('less_than_equal', 'Less than or equal to'), ('contains', 'Contains'), ('starts-with', 'Starts with'), ('ends-with', 'Ends with')])), ('value', wagtail.core.blocks.CharBlock(help_text='', max_length=255, required=True))])), ('blank_condition', wagtail.core.blocks.StructBlock([('field_name', wagtail.core.blocks.CharBlock(help_text='The name of a field in the form', max_length=255, required=True)), ('rule', wagtail.core.blocks.ChoiceBlock(choices=[('is_blank', 'Is blank'), ('is_not_blank', 'Is not blank')]))]))], required=False))], help_text='Add conditional rules to show or hide fields depending on the value of other fields in the form.', required=False))], label='HTML')), ('dropdown', wagtail.core.blocks.StructBlock([('label', wagtail.core.blocks.CharBlock(help_text='The label of the form field.', max_length=255, required=True)), ('required', wagtail.core.blocks.BooleanBlock(default=False, help_text='Tick this box to make this a required field.', required=False)), ('choices', wagtail.core.blocks.ListBlock(wagtail.core.blocks.TextBlock(icon='extraicons--heading-icon', required=True))), ('empty_label', wagtail.core.blocks.CharBlock(max_length=255, required=False)), ('default_value', wagtail.core.blocks.CharBlock(help_text='Set a default value for this field.', max_length=255, required=False)), ('help_text', wagtail.core.blocks.CharBlock(help_text='Text to assist the user in populating this field.', max_length=255, required=False)), ('rules', wagtail.core.blocks.StructBlock([('action', wagtail.core.blocks.ChoiceBlock(choices=[('show', 'Show'), ('hide', 'Hide')], help_text='What conditional action would you like to perform on this field?')), ('conditions', wagtail.core.blocks.StreamBlock([('condition', wagtail.core.blocks.StructBlock([('field_name', wagtail.core.blocks.CharBlock(help_text='The name of a field in the form', max_length=255, required=True)), ('rule', wagtail.core.blocks.ChoiceBlock(choices=[('is', 'Is equal to'), ('is_not', 'Is not equal to'), ('greater_than', 'Greater than'), ('greater_than_equal', 'Greater than or equal to'), ('less_than', 'Less than'), ('less_than_equal', 'Less than or equal to'), ('contains', 'Contains'), ('starts-with', 'Starts with'), ('ends-with', 'Ends with')])), ('value', wagtail.core.blocks.CharBlock(help_text='', max_length=255, required=True))])), ('blank_condition', wagtail.core.blocks.StructBlock([('field_name', wagtail.core.blocks.CharBlock(help_text='The name of a field in the form', max_length=255, required=True)), ('rule', wagtail.core.blocks.ChoiceBlock(choices=[('is_blank', 'Is blank'), ('is_not_blank', 'Is not blank')]))]))], required=False))], help_text='Add conditional rules to show or hide fields depending on the value of other fields in the form.', required=False))], label='Dropdown field')), ('radio', wagtail.core.blocks.StructBlock([('label', wagtail.core.blocks.CharBlock(help_text='The label of the form field.', max_length=255, required=True)), ('required', wagtail.core.blocks.BooleanBlock(default=False, help_text='Tick this box to make this a required field.', required=False)), ('choices', wagtail.core.blocks.ListBlock(wagtail.core.blocks.TextBlock(icon='extraicons--heading-icon', required=True))), ('default_value', wagtail.core.blocks.CharBlock(help_text='Set a default value for this field.', max_length=255, required=False)), ('help_text', wagtail.core.blocks.CharBlock(help_text='Text to assist the user in populating this field.', max_length=255, required=False)), ('display_side_by_side', wagtail.core.blocks.BooleanBlock(help_text='Display these items side by side?', required=False)), ('rules', wagtail.core.blocks.StructBlock([('action', wagtail.core.blocks.ChoiceBlock(choices=[('show', 'Show'), ('hide', 'Hide')], help_text='What conditional action would you like to perform on this field?')), ('conditions', wagtail.core.blocks.StreamBlock([('condition', wagtail.core.blocks.StructBlock([('field_name', wagtail.core.blocks.CharBlock(help_text='The name of a field in the form', max_length=255, required=True)), ('rule', wagtail.core.blocks.ChoiceBlock(choices=[('is', 'Is equal to'), ('is_not', 'Is not equal to'), ('greater_than', 'Greater than'), ('greater_than_equal', 'Greater than or equal to'), ('less_than', 'Less than'), ('less_than_equal', 'Less than or equal to'), ('contains', 'Contains'), ('starts-with', 'Starts with'), ('ends-with', 'Ends with')])), ('value', wagtail.core.blocks.CharBlock(help_text='', max_length=255, required=True))])), ('blank_condition', wagtail.core.blocks.StructBlock([('field_name', wagtail.core.blocks.CharBlock(help_text='The name of a field in the form', max_length=255, required=True)), ('rule', wagtail.core.blocks.ChoiceBlock(choices=[('is_blank', 'Is blank'), ('is_not_blank', 'Is not blank')]))]))], required=False))], help_text='Add conditional rules to show or hide fields depending on the value of other fields in the form.', required=False))], label='Radio field')), ('checkboxes', wagtail.core.blocks.StructBlock([('label', wagtail.core.blocks.CharBlock(help_text='The label of the form field.', max_length=255, required=True)), ('required', wagtail.core.blocks.BooleanBlock(default=False, help_text='Tick this box to make this a required field.', required=False)), ('choices', wagtail.core.blocks.ListBlock(wagtail.core.blocks.TextBlock(icon='extraicons--heading-icon', required=True))), ('default_value', wagtail.core.blocks.ListBlock(wagtail.core.blocks.TextBlock(help_text='Enter a value that matches a checkbox choice above to have it ticked by default.', icon='extraicons--heading-icon', required=True))), ('help_text', wagtail.core.blocks.CharBlock(help_text='Text to assist the user in populating this field.', max_length=255, required=False)), ('display_side_by_side', wagtail.core.blocks.BooleanBlock(help_text='Display these items side by side?', required=False)), ('rules', wagtail.core.blocks.StructBlock([('action', wagtail.core.blocks.ChoiceBlock(choices=[('show', 'Show'), ('hide', 'Hide')], help_text='What conditional action would you like to perform on this field?')), ('conditions', wagtail.core.blocks.StreamBlock([('condition', wagtail.core.blocks.StructBlock([('field_name', wagtail.core.blocks.CharBlock(help_text='The name of a field in the form', max_length=255, required=True)), ('rule', wagtail.core.blocks.ChoiceBlock(choices=[('is', 'Is equal to'), ('is_not', 'Is not equal to'), ('greater_than', 'Greater than'), ('greater_than_equal', 'Greater than or equal to'), ('less_than', 'Less than'), ('less_than_equal', 'Less than or equal to'), ('contains', 'Contains'), ('starts-with', 'Starts with'), ('ends-with', 'Ends with')])), ('value', wagtail.core.blocks.CharBlock(help_text='', max_length=255, required=True))])), ('blank_condition', wagtail.core.blocks.StructBlock([('field_name', wagtail.core.blocks.CharBlock(help_text='The name of a field in the form', max_length=255, required=True)), ('rule', wagtail.core.blocks.ChoiceBlock(choices=[('is_blank', 'Is blank'), ('is_not_blank', 'Is not blank')]))]))], required=False))], help_text='Add conditional rules to show or hide fields depending on the value of other fields in the form.', required=False))], label='Checkboxes field')), ('checkbox', wagtail.core.blocks.StructBlock([('label', wagtail.core.blocks.CharBlock(help_text='The label of the form field.', max_length=255, required=True)), ('required', wagtail.core.blocks.BooleanBlock(default=False, help_text='Tick this box to make this a required field.', required=False)), ('display_checkbox_label', wagtail.core.blocks.BooleanBlock(default=False, help_text='Do you want the checkbox label to display? If not you should populate help_text.', required=False)), ('help_text', wagtail.core.blocks.CharBlock(max_length=255, required=False)), ('rules', wagtail.core.blocks.StructBlock([('action', wagtail.core.blocks.ChoiceBlock(choices=[('show', 'Show'), ('hide', 'Hide')], help_text='What conditional action would you like to perform on this field?')), ('conditions', wagtail.core.blocks.StreamBlock([('condition', wagtail.core.blocks.StructBlock([('field_name', wagtail.core.blocks.CharBlock(help_text='The name of a field in the form', max_length=255, required=True)), ('rule', wagtail.core.blocks.ChoiceBlock(choices=[('is', 'Is equal to'), ('is_not', 'Is not equal to'), ('greater_than', 'Greater than'), ('greater_than_equal', 'Greater than or equal to'), ('less_than', 'Less than'), ('less_than_equal', 'Less than or equal to'), ('contains', 'Contains'), ('starts-with', 'Starts with'), ('ends-with', 'Ends with')])), ('value', wagtail.core.blocks.CharBlock(help_text='', max_length=255, required=True))])), ('blank_condition', wagtail.core.blocks.StructBlock([('field_name', wagtail.core.blocks.CharBlock(help_text='The name of a field in the form', max_length=255, required=True)), ('rule', wagtail.core.blocks.ChoiceBlock(choices=[('is_blank', 'Is blank'), ('is_not_blank', 'Is not blank')]))]))], required=False))], help_text='Add conditional rules to show or hide fields depending on the value of other fields in the form.', required=False))], label='Checkbox field')), ('multiselect', wagtail.core.blocks.StructBlock([('label', wagtail.core.blocks.CharBlock(help_text='The label of the form field.', max_length=255, required=True)), ('required', wagtail.core.blocks.BooleanBlock(default=False, help_text='Tick this box to make this a required field.', required=False)), ('choices', wagtail.core.blocks.ListBlock(wagtail.core.blocks.TextBlock(icon='extraicons--heading-icon', required=True))), ('default_value', wagtail.core.blocks.CharBlock(help_text='Set a default value for this field.', max_length=255, required=False)), ('help_text', wagtail.core.blocks.CharBlock(help_text='Text to assist the user in populating this field.', max_length=255, required=False)), ('rules', wagtail.core.blocks.StructBlock([('action', wagtail.core.blocks.ChoiceBlock(choices=[('show', 'Show'), ('hide', 'Hide')], help_text='What conditional action would you like to perform on this field?')), ('conditions', wagtail.core.blocks.StreamBlock([('condition', wagtail.core.blocks.StructBlock([('field_name', wagtail.core.blocks.CharBlock(help_text='The name of a field in the form', max_length=255, required=True)), ('rule', wagtail.core.blocks.ChoiceBlock(choices=[('is', 'Is equal to'), ('is_not', 'Is not equal to'), ('greater_than', 'Greater than'), ('greater_than_equal', 'Greater than or equal to'), ('less_than', 'Less than'), ('less_than_equal', 'Less than or equal to'), ('contains', 'Contains'), ('starts-with', 'Starts with'), ('ends-with', 'Ends with')])), ('value', wagtail.core.blocks.CharBlock(help_text='', max_length=255, required=True))])), ('blank_condition', wagtail.core.blocks.StructBlock([('field_name', wagtail.core.blocks.CharBlock(help_text='The name of a field in the form', max_length=255, required=True)), ('rule', wagtail.core.blocks.ChoiceBlock(choices=[('is_blank', 'Is blank'), ('is_not_blank', 'Is not blank')]))]))], required=False))], help_text='Add conditional rules to show or hide fields depending on the value of other fields in the form.', required=False))], label='Multiselect field')), ('multiline', wagtail.core.blocks.StructBlock([('label', wagtail.core.blocks.CharBlock(help_text='The label of the form field.', max_length=255, required=True)), ('required', wagtail.core.blocks.BooleanBlock(default=False, help_text='Tick this box to make this a required field.', required=False)), ('default_value', wagtail.core.blocks.CharBlock(help_text='Set a default value for this field.', max_length=255, required=False)), ('help_text', wagtail.core.blocks.CharBlock(help_text='Text to assist the user in populating this field.', max_length=255, required=False)), ('rules', wagtail.core.blocks.StructBlock([('action', wagtail.core.blocks.ChoiceBlock(choices=[('show', 'Show'), ('hide', 'Hide')], help_text='What conditional action would you like to perform on this field?')), ('conditions', wagtail.core.blocks.StreamBlock([('condition', wagtail.core.blocks.StructBlock([('field_name', wagtail.core.blocks.CharBlock(help_text='The name of a field in the form', max_length=255, required=True)), ('rule', wagtail.core.blocks.ChoiceBlock(choices=[('is', 'Is equal to'), ('is_not', 'Is not equal to'), ('greater_than', 'Greater than'), ('greater_than_equal', 'Greater than or equal to'), ('less_than', 'Less than'), ('less_than_equal', 'Less than or equal to'), ('contains', 'Contains'), ('starts-with', 'Starts with'), ('ends-with', 'Ends with')])), ('value', wagtail.core.blocks.CharBlock(help_text='', max_length=255, required=True))])), ('blank_condition', wagtail.core.blocks.StructBlock([('field_name', wagtail.core.blocks.CharBlock(help_text='The name of a field in the form', max_length=255, required=True)), ('rule', wagtail.core.blocks.ChoiceBlock(choices=[('is_blank', 'Is blank'), ('is_not_blank', 'Is not blank')]))]))], required=False))], help_text='Add conditional rules to show or hide fields depending on the value of other fields in the form.', required=False))], label='Multiline field')), ('url', wagtail.core.blocks.StructBlock([('label', wagtail.core.blocks.CharBlock(help_text='The label of the form field.', max_length=255, required=True)), ('required', wagtail.core.blocks.BooleanBlock(default=False, help_text='Tick this box to make this a required field.', required=False)), ('max_length', wagtail.core.blocks.IntegerBlock(help_text='Set a maximum length for this field. e.g. 100', required=False)), ('default_value', wagtail.core.blocks.CharBlock(help_text='Set a default value for this field.', max_length=255, required=False)), ('help_text', wagtail.core.blocks.CharBlock(help_text='Text to assist the user in populating this field.', max_length=255, required=False)), ('rules', wagtail.core.blocks.StructBlock([('action', wagtail.core.blocks.ChoiceBlock(choices=[('show', 'Show'), ('hide', 'Hide')], help_text='What conditional action would you like to perform on this field?')), ('conditions', wagtail.core.blocks.StreamBlock([('condition', wagtail.core.blocks.StructBlock([('field_name', wagtail.core.blocks.CharBlock(help_text='The name of a field in the form', max_length=255, required=True)), ('rule', wagtail.core.blocks.ChoiceBlock(choices=[('is', 'Is equal to'), ('is_not', 'Is not equal to'), ('greater_than', 'Greater than'), ('greater_than_equal', 'Greater than or equal to'), ('less_than', 'Less than'), ('less_than_equal', 'Less than or equal to'), ('contains', 'Contains'), ('starts-with', 'Starts with'), ('ends-with', 'Ends with')])), ('value', wagtail.core.blocks.CharBlock(help_text='', max_length=255, required=True))])), ('blank_condition', wagtail.core.blocks.StructBlock([('field_name', wagtail.core.blocks.CharBlock(help_text='The name of a field in the form', max_length=255, required=True)), ('rule', wagtail.core.blocks.ChoiceBlock(choices=[('is_blank', 'Is blank'), ('is_not_blank', 'Is not blank')]))]))], required=False))], help_text='Add conditional rules to show or hide fields depending on the value of other fields in the form.', required=False))], label='URL field')), ('hidden', wagtail.core.blocks.StructBlock([('label', wagtail.core.blocks.CharBlock(help_text='The label of the form field.', max_length=255, required=True)), ('default_value', wagtail.core.blocks.CharBlock(max_length=255, required=True)), ('rules', wagtail.core.blocks.StructBlock([('action', wagtail.core.blocks.ChoiceBlock(choices=[('show', 'Show'), ('hide', 'Hide')], help_text='What conditional action would you like to perform on this field?')), ('conditions', wagtail.core.blocks.StreamBlock([('condition', wagtail.core.blocks.StructBlock([('field_name', wagtail.core.blocks.CharBlock(help_text='The name of a field in the form', max_length=255, required=True)), ('rule', wagtail.core.blocks.ChoiceBlock(choices=[('is', 'Is equal to'), ('is_not', 'Is not equal to'), ('greater_than', 'Greater than'), ('greater_than_equal', 'Greater than or equal to'), ('less_than', 'Less than'), ('less_than_equal', 'Less than or equal to'), ('contains', 'Contains'), ('starts-with', 'Starts with'), ('ends-with', 'Ends with')])), ('value', wagtail.core.blocks.CharBlock(help_text='', max_length=255, required=True))])), ('blank_condition', wagtail.core.blocks.StructBlock([('field_name', wagtail.core.blocks.CharBlock(help_text='The name of a field in the form', max_length=255, required=True)), ('rule', wagtail.core.blocks.ChoiceBlock(choices=[('is_blank', 'Is blank'), ('is_not_blank', 'Is not blank')]))]))], required=False))], help_text='Add conditional rules to show or hide fields depending on the value of other fields in the form.', required=False))], label='Hidden field')), ('number', wagtail.core.blocks.StructBlock([('label', wagtail.core.blocks.CharBlock(help_text='The label of the form field.', max_length=255, required=True)), ('required', wagtail.core.blocks.BooleanBlock(default=False, help_text='Tick this box to make this a required field.', required=False)), ('default_value', wagtail.core.blocks.CharBlock(help_text='Set a default value for this field.', max_length=255, required=False)), ('help_text', wagtail.core.blocks.CharBlock(help_text='Text to assist the user in populating this field.', max_length=255, required=False)), ('rules', wagtail.core.blocks.StructBlock([('action', wagtail.core.blocks.ChoiceBlock(choices=[('show', 'Show'), ('hide', 'Hide')], help_text='What conditional action would you like to perform on this field?')), ('conditions', wagtail.core.blocks.StreamBlock([('condition', wagtail.core.blocks.StructBlock([('field_name', wagtail.core.blocks.CharBlock(help_text='The name of a field in the form', max_length=255, required=True)), ('rule', wagtail.core.blocks.ChoiceBlock(choices=[('is', 'Is equal to'), ('is_not', 'Is not equal to'), ('greater_than', 'Greater than'), ('greater_than_equal', 'Greater than or equal to'), ('less_than', 'Less than'), ('less_than_equal', 'Less than or equal to'), ('contains', 'Contains'), ('starts-with', 'Starts with'), ('ends-with', 'Ends with')])), ('value', wagtail.core.blocks.CharBlock(help_text='', max_length=255, required=True))])), ('blank_condition', wagtail.core.blocks.StructBlock([('field_name', wagtail.core.blocks.CharBlock(help_text='The name of a field in the form', max_length=255, required=True)), ('rule', wagtail.core.blocks.ChoiceBlock(choices=[('is_blank', 'Is blank'), ('is_not_blank', 'Is not blank')]))]))], required=False))], help_text='Add conditional rules to show or hide fields depending on the value of other fields in the form.', required=False))], label='Number field'))], default=None, help_text='Add fields to the form', null=True)),
                ('thanks_page_title', models.CharField(blank=True, default=None, help_text='The title for the thanks page. Defaults to the normal page title if left blank.', max_length=150, null=True)),
                ('thanks_page_content', wagtail.core.fields.RichTextField(default=None, help_text='Content to display on the form thank you page.', null=True)),
                ('submit_button_text', models.CharField(default='Submit', help_text='The text to display on the form submission button', max_length=30)),
                ('use_browser_validation', models.BooleanField(blank=True, default=False, help_text='Tick this to use the in-built browser validation on fields')),
            ],
            options={
                'abstract': False,
            },
            bases=('wagtailcore.page', models.Model),
        ),
        migrations.CreateModel(
            name='FormField',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('sort_order', models.IntegerField(blank=True, editable=False, null=True)),
                ('label', models.CharField(help_text='The label of the form field', max_length=255, verbose_name='label')),
                ('required', models.BooleanField(default=True, verbose_name='required')),
                ('choices', models.TextField(blank=True, help_text='Comma separated list of choices. Only applicable in checkboxes, radio and dropdown.', verbose_name='choices')),
                ('default_value', models.CharField(blank=True, help_text='Default value. Comma separated values supported for checkboxes.', max_length=255, verbose_name='default value')),
                ('help_text', models.CharField(blank=True, max_length=255, verbose_name='help text')),
                ('field_type', models.CharField(choices=[('singleline', 'Single line text'), ('multiline', 'Multi-line text'), ('email', 'Email'), ('number', 'Number'), ('url', 'URL'), ('checkbox', 'Checkbox'), ('checkboxes', 'Checkboxes'), ('dropdown', 'Drop down'), ('multiselect', 'Multiple select'), ('radio', 'Radio buttons'), ('date', 'Date'), ('hidden', 'Hidden field'), ('currency', 'Currency field'), ('simpledate', 'Date'), ('phone', 'Phone')], max_length=16, verbose_name='field type')),
                ('rule_action', models.CharField(blank=True, choices=[('show', 'Show'), ('hide', 'Hide')], default='', max_length=10)),
                ('html_value', wagtail.core.fields.RichTextField(blank=True, default=None, null=True)),
                ('max_length', models.IntegerField(blank=True, default=None, null=True)),
                ('empty_label', models.CharField(blank=True, default=None, max_length=255, null=True)),
                ('display_side_by_side', models.BooleanField(default=False)),
                ('display_checkbox_label', models.BooleanField(default=False)),
                ('page', modelcluster.fields.ParentalKey(on_delete=django.db.models.deletion.CASCADE, related_name='form_fields', to='wagtail_advanced_form_builder.FormPage')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='EmailFormField',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('sort_order', models.IntegerField(blank=True, editable=False, null=True)),
                ('label', models.CharField(help_text='The label of the form field', max_length=255, verbose_name='label')),
                ('required', models.BooleanField(default=True, verbose_name='required')),
                ('choices', models.TextField(blank=True, help_text='Comma separated list of choices. Only applicable in checkboxes, radio and dropdown.', verbose_name='choices')),
                ('default_value', models.CharField(blank=True, help_text='Default value. Comma separated values supported for checkboxes.', max_length=255, verbose_name='default value')),
                ('help_text', models.CharField(blank=True, max_length=255, verbose_name='help text')),
                ('field_type', models.CharField(choices=[('singleline', 'Single line text'), ('multiline', 'Multi-line text'), ('email', 'Email'), ('number', 'Number'), ('url', 'URL'), ('checkbox', 'Checkbox'), ('checkboxes', 'Checkboxes'), ('dropdown', 'Drop down'), ('multiselect', 'Multiple select'), ('radio', 'Radio buttons'), ('date', 'Date'), ('hidden', 'Hidden field'), ('currency', 'Currency field'), ('simpledate', 'Date'), ('phone', 'Phone')], max_length=16, verbose_name='field type')),
                ('rule_action', models.CharField(blank=True, choices=[('show', 'Show'), ('hide', 'Hide')], default='', max_length=10)),
                ('html_value', wagtail.core.fields.RichTextField(blank=True, default=None, null=True)),
                ('max_length', models.IntegerField(blank=True, default=None, null=True)),
                ('empty_label', models.CharField(blank=True, default=None, max_length=255, null=True)),
                ('display_side_by_side', models.BooleanField(default=False)),
                ('display_checkbox_label', models.BooleanField(default=False)),
                ('page', modelcluster.fields.ParentalKey(on_delete=django.db.models.deletion.CASCADE, related_name='form_fields', to='wagtail_advanced_form_builder.EmailFormPage')),
            ],
            options={
                'abstract': False,
            },
        ),
    ]



from django.db import models
from modelcluster.fields import ParentalKey
from .abstract_advanced_form_field import AbstractAdvancedFormField


class FormField(AbstractAdvancedFormField):

    page = ParentalKey(
        'wagtail_advanced_form_builder.FormPage',
        on_delete=models.CASCADE,
        related_name='form_fields'
    )



from wagtail.core.models import Page

from wagtail_advanced_form_builder.models.abstract_advanced_form import AbstractAdvancedForm


class FormPage(AbstractAdvancedForm):

    content_panels = Page.content_panels + AbstractAdvancedForm.content_panels

    settings_panels = Page.settings_panels + AbstractAdvancedForm.settings_panels




from .base_field_block import BaseFieldBlock


class NumberFieldBlock(BaseFieldBlock):

    choices = None

    html = None

    display_checkbox_label = None

    empty_label = None

    display_side_by_side = None

    placeholder = None

    max_length = None

    class Meta:
        form_classname = 'waf--field'
        icon = 'extraicons--number'



#!/usr/bin/env python
import io

from setuptools import setup, find_packages

# Hack to prevent "TypeError: 'NoneType' object is not callable" error
# in multiprocessing/util.py _exit_function when setup.py exits
# (see http://www.eby-sarna.com/pipermail/peak/2010-May/003357.html)
try:
    import multiprocessing
except ImportError:
    pass

with io.open("README.md", encoding="utf-8") as fh:
    long_description = fh.read()

setup(
    name="wagtail-advanced-form-builder",
    version="0.1.8",
    description="Wagtail Advanced Form Builder",
    long_description=long_description,
    author="Richard Blake (Octave)",
    author_email="richard.blake@octave.nz",
    url="https://github.com/octavenz/wagtail-advanced-form-builder",
    packages=find_packages(exclude=("build_test",)),
    include_package_data=True,
    license="BSD",
    classifiers=[
        "Development Status :: 4 - Beta",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: BSD License",
        "Operating System :: OS Independent",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
    ],
    install_requires=["Django>=2.2,<3.2", "Wagtail>=2.7,<2.11", "wagtailextraicons"],
    zip_safe=False,
)
